@@ -1,32 +1,51 @@
-context("Diversity index")
-
-birds <- matrix(c(1.4, 4.3, 2.9, 8.6, 4.2, 15.7, 2.0, 50, 1, 11.4, 11.4, 4.3,
-                  13.0, 14.3, 8.6, 7.1, 10.0, 1.4, 2.9, 5.7, 1.4, 11.4, 2.9,
-                  4.3, 1.4, 2.9,
-                  0, 0, 0, 2.9, 0, 0, 0, 10, 0, 0, 5.7, 2.5, 5.7, 8.6, 5.7,
-                  2.9, 0, 0, 2.9, 0, 0, 5.7, 0, 2.9, 0, 2.9),
-                nrow = 2, byrow = TRUE)
-
-# Heterogeneity index ==========================================================
 test_that("Heterogeneity", {
-  count <- as(birds, "CountMatrix")
+  skip_if_not_installed("folio")
+  data("chevelon", package = "folio")
+  counts <- as_count(chevelon)
+
   method <- c("berger", "brillouin", "mcintosh", "shannon", "simpson")
   for (i in method) {
-    index <- index_heterogeneity(count, method = i)
-    expect_s4_class(index, "HeterogeneityIndex")
-    expect_length(index@index, 2)
+    index <- index_heterogeneity(counts, method = i)
+    expect_length(index@values, nrow(counts))
+    expect_equal(get_method(index), i)
   }
-})
+  expect_type(get_index(index), "closure")
 
-# Evenness =====================================================================
+  boot <- with_seed(12345, bootstrap_heterogeneity(counts, method = "shannon", n = 30))
+  expect_snapshot(boot)
+
+  jack <- jackknife_heterogeneity(counts, method = "shannon")
+  expect_snapshot(jack)
+})
 test_that("Evenness", {
-  count <- as(birds, "CountMatrix")
+  skip_if_not_installed("folio")
+  data("chevelon", package = "folio")
+  counts <- as_count(chevelon)
+
   method <- c("brillouin", "mcintosh", "shannon", "simpson")
   for (i in method) {
-    index <- index_evenness(count, method = i)
-    expect_s4_class(index, "EvennessIndex")
-    expect_length(index@index, 2)
+    index <- index_evenness(counts, method = i)
+    expect_length(index@values, nrow(counts))
+    expect_equal(get_method(index), i)
   }
+  expect_type(get_index(index), "closure")
+
+  # boot <- with_seed(12345, bootstrap_evenness(counts, method = "shannon", n = 30))
+  # expect_snapshot(boot)
+
+  jack <- jackknife_evenness(counts, method = "shannon")
+  expect_snapshot(jack)
+})
+test_that("Shannon diversity test", {
+  # Data from Magurran 1988, p. 145-149
+  birds <- CountMatrix(
+    data = c(35, 26, 25, 21, 16, 11, 6, 5, 3, 3,
+             3, 3, 3, 2, 2, 2, 1, 1, 1, 1, 0, 0,
+             30, 30, 3, 65, 20, 11, 0, 4, 2, 14,
+             0, 3, 9, 0, 0, 5, 0, 0, 0, 0, 1, 1),
+    nrow = 2, byrow = TRUE, dimnames = list(c("oakwood", "spruce"), NULL))
+
+  expect_equal(round(test_diversity(birds)[1, 1], 5), 0.00046)
 })
 
 # Indices ======================================================================
@@ -99,4 +118,3 @@ test_that("Berger-Parker dominance", {
   n <- c(394, 3487, 275, 683, 22, 1, 0, 1, 6, 8, 1, 1, 2)
   expect_equal(round(dominanceBerger(n), 3), 0.714)
 })
-
