@@ -1,5 +1,3 @@
-context("Rarefaction")
-
 # Rarefaction ==================================================================
 test_that("Rarefaction", {
   # Data from Magurran 1988, p. 128-129
@@ -9,18 +7,9 @@ test_that("Rarefaction", {
                       dimnames = list(c(1, 2), NULL))
   expected <- c(`1` = 6.56, `2` = NA)
 
-  index <- rarefaction(trap, sample = 13, simplify = FALSE)
-  expect_type(index, "list")
-  expect_equal(round(index[[1]], digits = 2), expected)
-
-  index <- rarefaction(trap, sample = 13, simplify = TRUE)
-  expect_equal(dim(index), c(2, 1))
-
-  freq <- as(trap, "AbundanceMatrix")
-  expect_error(rarefaction(freq, 13))
-
-  incid <- as(trap, "IncidenceMatrix")
-  expect_error(rarefaction(incid, 13))
+  index <- rarefaction(trap, sample = 13)
+  expect_type(index, "double")
+  expect_equal(round(index, digits = 2), expected)
 })
 
 # Indices ======================================================================
